@@ -228,6 +228,11 @@ class Context(object):
             self.rounding == other.rounding
             )
 
+    def __hash__(self):
+        return hash((self.precision, self.emin, self.emax,
+                     self.subnormalize, self.rounding))
+
+
     @property
     def precision(self):
         return self._precision
@@ -523,7 +528,7 @@ class BigFloat(object):
         """Create BigFloat from integer, float, string or another BigFloat.
 
         If the context keyword argument is not given, the result
-        format and the rounding mode 
+        format and the rounding mode
 
         Uses the current precision and rounding mode, unless an
         alternative context is given.
